@@ -1,6 +1,3 @@
-import re
-import datetime
-import logging
 import twilio
 from twilio import TwilioException, TwilioRestException
 
@@ -10,7 +7,7 @@ from twilio.rest.resources.imports import (
 
 from twilio.rest.resources.util import (
     transform_params, format_name, parse_date, convert_boolean, convert_case,
-    convert_keys, normalize_dates
+    convert_keys, normalize_dates, UNSET_TIMEOUT
 )
 from twilio.rest.resources.base import (
     Response, Resource, InstanceResource, ListResource,
@@ -19,12 +16,10 @@ from twilio.rest.resources.base import (
 from twilio.rest.resources.phone_numbers import (
     AvailablePhoneNumber, AvailablePhoneNumbers, PhoneNumber, PhoneNumbers
 )
-from twilio.rest.resources.recordings import (
-    Recording, Recordings, Transcription, Transcriptions
-)
-from twilio.rest.resources.notifications import (
-    Notification, Notifications
-)
+from twilio.rest.resources.recordings import Recording, Recordings
+from twilio.rest.resources.transcriptions import Transcription, Transcriptions
+
+from twilio.rest.resources.notifications import Notification, Notifications
 from twilio.rest.resources.connect_apps import (
     ConnectApp, ConnectApps, AuthorizedConnectApp, AuthorizedConnectApps
 )
@@ -45,3 +40,9 @@ from twilio.rest.resources.applications import (
 from twilio.rest.resources.accounts import Account, Accounts
 
 from twilio.rest.resources.usage import Usage
+
+from twilio.rest.resources.messages import Message, Messages
+
+from twilio.rest.resources.media import Media, MediaList
+
+from twilio.rest.resources.sip import Sip
