@@ -1,10 +1,12 @@
 import logging
+import os
 from six import integer_types, string_types, binary_type, iteritems
 from twilio.compat import urlparse
 from twilio.compat import urlencode
 
 import twilio
 from twilio import TwilioException, TwilioRestException
+from twilio.rest.resources import UNSET_TIMEOUT
 from twilio.rest.resources.imports import parse_qs, httplib2, json
 from twilio.rest.resources.util import transform_params, parse_rfc2822_date
 
@@ -21,32 +23,66 @@ class Response(object):
         self.url = url
 
 
+def get_cert_file():
+    """ Get the cert file location or bail """
+    try:
+        # Apparently __file__ is not available in all places so wrapping this
+        # in a try/catch
+        current_path = os.path.realpath(__file__)
+        ca_cert_path = os.path.join(current_path, "..", "..", "..",
+                                    "conf", "cacert.pem")
+        return os.path.abspath(ca_cert_path)
+    except Exception:
+        # None means use the default system file
+        return None
+
+
 def make_request(method, url, params=None, data=None, headers=None,
                  cookies=None, files=None, auth=None, timeout=None,
                  allow_redirects=False, proxies=None):
-    """Sends an HTTP request Returns :class:`Response <models.Response>`
+    """Sends an HTTP request
+
+    :param str method: The HTTP method to use
+    :param str url: The URL to request
+    :param dict params: Query parameters to append to the URL
+    :param dict data: Parameters to go in the body of the HTTP request
+    :param dict headers: HTTP Headers to send with the request
+    :param float timeout: Socket/Read timeout for the request
+
+    :return: An http response
+    :rtype: A :class:`Response <models.Response>` object
 
     See the requests documentation for explanation of all these parameters
 
     Currently proxies, files, and cookies are all ignored
     """
-    http = httplib2.Http(timeout=timeout)
+    http = httplib2.Http(timeout=timeout, ca_certs=get_cert_file())
     http.follow_redirects = allow_redirects
 
     if auth is not None:
         http.add_credentials(auth[0], auth[1])
 
+    def encode_atom(atom):
+            if isinstance(atom, (integer_types, binary_type)):
+                return atom
+            elif isinstance(atom, string_types):
+                return atom.encode('utf-8')
+            else:
+                raise ValueError('list elements should be an integer, '
+                                 'binary, or string')
+
     if data is not None:
         udata = {}
         for k, v in iteritems(data):
             key = k.encode('utf-8')
-            if isinstance(v, (integer_types, binary_type)):
-                udata[key] = v
-            elif isinstance(v, string_types):
-                udata[key] = v.encode('utf-8')
+            if isinstance(v, (list, tuple, set)):
+                udata[key] = [encode_atom(x) for x in v]
+            elif isinstance(v, (integer_types, binary_type, string_types)):
+                udata[key] = encode_atom(v)
             else:
-                raise ValueError('data should be an integer, binary, or string')
-        data = urlencode(udata)
+                raise ValueError('data should be an integer, '
+                                 'binary, or string, or sequence ')
+        data = urlencode(udata, doseq=True)
 
     if params is not None:
         enc_params = urlencode(params, doseq=True)
@@ -64,6 +100,11 @@ def make_request(method, url, params=None, data=None, headers=None,
 def make_twilio_request(method, uri, **kwargs):
     """
     Make a request to Twilio. Throws an error
+
+    :return: a requests-like HTTP response
+    :rtype: :class:`RequestsResponse`
+    :raises: :exc:`~twilio.TwilioRestException` if the response is a 400 or
+        500-level response.
     """
     headers = kwargs.get("headers", {})
     headers["User-Agent"] = "twilio-python/%s" % twilio.__version__
@@ -99,9 +140,10 @@ class Resource(object):
 
     name = "Resource"
 
-    def __init__(self, base_uri, auth):
+    def __init__(self, base_uri, auth, timeout=UNSET_TIMEOUT):
         self.base_uri = base_uri
         self.auth = auth
+        self.timeout = timeout
 
     def __eq__(self, other):
         return (isinstance(other, self.__class__)
@@ -117,8 +159,10 @@ class Resource(object):
         """
         Send an HTTP request to the resource.
 
-        Raise a TwilioRestException
+        :raises: a :exc:`~twilio.TwilioRestException`
         """
+        if 'timeout' not in kwargs and self.timeout is not UNSET_TIMEOUT:
+            kwargs['timeout'] = self.timeout
         resp = make_twilio_request(method, uri, auth=self.auth, **kwargs)
 
         logging.debug(resp.content)
@@ -135,6 +179,14 @@ class Resource(object):
 
 
 class InstanceResource(Resource):
+    """ The object representation of an instance response from the Twilio API
+
+    :param parent: The parent list class for this instance resource.
+        For example, the parent for a :class:`~twilio.rest.resources.Call` would
+        be a :class:`~twilio.rest.resources.Calls` object.
+    :type parent: :class:`~twilio.rest.resources.ListResource`
+    :param str sid: The 34-character unique identifier for this instance
+    """
 
     subresources = []
     id_key = "sid"
@@ -142,7 +194,11 @@ class InstanceResource(Resource):
     def __init__(self, parent, sid):
         self.parent = parent
         self.name = sid
-        super(InstanceResource, self).__init__(parent.uri, parent.auth)
+        super(InstanceResource, self).__init__(
+            parent.uri,
+            parent.auth,
+            parent.timeout
+        )
 
     def load(self, entries):
         if "from" in entries.keys():
@@ -153,7 +209,7 @@ class InstanceResource(Resource):
             del entries["uri"]
 
         for key in entries.keys():
-            if key.startswith("date_"):
+            if key.startswith("date_") and isinstance(entries[key], str):
                 entries[key] = parse_rfc2822_date(entries[key])
 
         self.__dict__.update(entries)
@@ -163,16 +219,33 @@ class InstanceResource(Resource):
         Load all subresources
         """
         for resource in self.subresources:
-            list_resource = resource(self.uri, self.parent.auth)
+            list_resource = resource(
+                self.uri,
+                self.parent.auth,
+                self.parent.timeout
+            )
             self.__dict__[list_resource.key] = list_resource
 
     def update_instance(self, **kwargs):
+        """ Make a POST request to the API to update an object's properties
+
+        :return: None, this is purely side effecting
+        :raises: a :class:`~twilio.rest.RestException` on failure
+        """
         a = self.parent.update(self.name, **kwargs)
         self.load(a.__dict__)
 
     def delete_instance(self):
+        """ Make a DELETE request to the API to delete the object
+
+        :return: None, this is purely side effecting
+        :raises: a :class:`~twilio.rest.RestException` on failure
+        """
         return self.parent.delete(self.name)
 
+    def __str__(self):
+        return "<{0} {1}>".format(self.__class__.__name__, self.name[0:5])
+
 
 class ListResource(Resource):
 
@@ -188,7 +261,19 @@ class ListResource(Resource):
             self.key = self.name.lower()
 
     def get(self, sid):
-        """Return an instance resource"""
+        """ Get an instance resource by its sid
+
+        Usage:
+
+        .. code-block:: python
+
+            message = client.messages.get("SM1234")
+            print message.body
+
+        :rtype: :class:`~twilio.rest.resources.InstanceResource`
+        :raises: a :exc:`~twilio.TwilioRestException` if a resource with that
+            sid does not exist, or the request fails
+        """
         return self.get_instance(sid)
 
     def get_instance(self, sid):
@@ -201,8 +286,8 @@ class ListResource(Resource):
         """
         Query the list resource for a list of InstanceResources.
 
-        Raises a TwilioRestException if requesting a page of results that does
-        not exist.
+        Raises a :exc:`~twilio.TwilioRestException` if requesting a page of
+        results that does not exist.
 
         :param dict params: List of URL parameters to be included in request
         :param int page: The page of results to retrieve (most recent at 0)
@@ -228,8 +313,8 @@ class ListResource(Resource):
         resp, instance = self.request("POST", self.uri,
                                       data=transform_params(body))
 
-        if resp.status_code != 201:
-            raise TwilioRestException(resp.status,
+        if resp.status_code not in (200, 201):
+            raise TwilioRestException(resp.status_code,
                                       self.uri, "Resource not created")
 
         return self.load_instance(instance)
@@ -256,15 +341,41 @@ class ListResource(Resource):
         return self.load_instance(entry)
 
     def count(self):
+        """ Get the total number of instances for this resource
+
+        Note: this query can be slow if you have many instances.
+
+        :return: the total number of instances
+        :rtype: int
+        :raises: a :exc:`~twilio.TwilioRestException` if the request fails
+
+        Example usage:
+
+        .. code-block:: python
+
+            print client.calls.count() # prints 323
         """
-        Return the number of instance resources contained in this list resource
-        """
+        # XXX: this should make a request with PageSize=1 to return as quickly
+        # as possible
         resp, page = self.request("GET", self.uri)
         return page["total"]
 
     def iter(self, **kwargs):
-        """
-        Return all instance resources using an iterator
+        """ Return all instance resources using an iterator
+
+        This will fetch a page of resources from the API and yield them in
+        turn. When the page is exhausted, this will make a request to the API
+        to retrieve the next page. Hence you may notice a pattern - the library
+        will loop through 50 objects very quickly, but there will be a delay
+        retrieving the 51st as the library must make another request to the API
+        for resources.
+
+        Example usage:
+
+        .. code-block:: python
+
+            for message in client.messages:
+                print message.sid
         """
         params = transform_params(kwargs)
 
@@ -288,3 +399,15 @@ class ListResource(Resource):
         instance.load(data)
         instance.load_subresources()
         return instance
+
+    def __str__(self):
+        return '<{} ({})>'.format(self.__class__.__name__, self.count())
+        return '<{0} ({1})>'.format(self.__class__.__name__, self.count())
+
+    def list(self, **kw):
+        """Query the list resource for a list of InstanceResources.
+
+        :param int page: The page of results to retrieve (most recent at 0)
+        :param int page_size: The number of results to be returned.
+        """
+        return self.get_instances(kw)
