@@ -2,13 +2,53 @@ import re
 
 from twilio import TwilioException
 from twilio.rest.resources.util import change_dict_key, transform_params
+from twilio.rest.resources.util import UNSET_TIMEOUT
 from twilio.rest.resources import InstanceResource, ListResource
 
 
 class AvailablePhoneNumber(InstanceResource):
-    """ An available phone number resource """
+    """ An available phone number resource
+
+   .. attribute:: friendly_name
+
+      A nicely-formatted version of the phone number.
+
+   .. attribute:: phone_number
+
+      The phone number, in E.164 (i.e. "+1") format.
+
+   .. attribute:: lata
+
+      The LATA of this phone number.
+
+   .. attribute:: rate_center
+
+      The rate center of this phone number.
+
+   .. attribute:: latitude
+
+      The latitude coordinate of this phone number.
+
+   .. attribute:: longitude
+
+      The longitude coordinate of this phone number.
+
+   .. attribute:: region
+
+      The two-letter state or province abbreviation of this phone number.
+
+   .. attribute:: postal_code
+
+      The postal (zip) code of this phone number.
+
+   .. attribute:: iso_country
+
+        The country for this number
+
+    """
 
     def __init__(self, parent):
+        # Available Phone Numbers have no sid.
         super(AvailablePhoneNumber, self).__init__(parent, "")
         self.name = ""
 
@@ -25,8 +65,8 @@ class AvailablePhoneNumbers(ListResource):
 
     types = {"local": "Local", "tollfree": "TollFree"}
 
-    def __init__(self, base_uri, auth, phone_numbers):
-        super(AvailablePhoneNumbers, self).__init__(base_uri, auth)
+    def __init__(self, base_uri, auth, timeout, phone_numbers):
+        super(AvailablePhoneNumbers, self).__init__(base_uri, auth, timeout)
         self.phone_numbers = phone_numbers
 
     def get(self, sid):
@@ -56,6 +96,85 @@ class AvailablePhoneNumbers(ListResource):
 
 
 class PhoneNumber(InstanceResource):
+    """ An IncomingPhoneNumber object
+
+   .. attribute:: sid
+
+      A 34 character string that uniquely identifies this resource.
+
+   .. attribute:: date_created
+
+      The date that this resource was created, given as GMT RFC 2822 format.
+
+   .. attribute:: date_updated
+
+      The date that this resource was last updated, given as GMT RFC 2822 format.
+
+   .. attribute:: friendly_name
+
+      A human readable descriptive text for this resource, up to 64 characters long. By default, the FriendlyName is a nicely formatted version of the phone number.
+
+   .. attribute:: account_sid
+
+      The unique id of the Account responsible for this phone number.
+
+   .. attribute:: phone_number
+
+      The incoming phone number. e.g., +16175551212 (E.164 format)
+
+   .. attribute:: api_version
+
+      Calls to this phone number will start a new TwiML session with this API version.
+
+   .. attribute:: voice_caller_id_lookup
+
+      Look up the caller's caller-ID name from the CNAM database (additional charges apply). Either true or false.
+
+   .. attribute:: voice_url
+
+      The URL Twilio will request when this phone number receives a call.
+
+   .. attribute:: voice_method
+
+      The HTTP method Twilio will use when requesting the above Url. Either GET or POST.
+
+   .. attribute:: voice_fallback_url
+
+      The URL that Twilio will request if an error occurs retrieving or executing the TwiML requested by Url.
+
+   .. attribute:: voice_fallback_method
+
+      The HTTP method Twilio will use when requesting the VoiceFallbackUrl. Either GET or POST.
+
+   .. attribute:: status_callback
+
+      The URL that Twilio will request to pass status parameters (such as call ended) to your application.
+
+   .. attribute:: status_callback_method
+
+      The HTTP method Twilio will use to make requests to the StatusCallback URL. Either GET or POST.
+
+   .. attribute:: sms_url
+
+      The URL Twilio will request when receiving an incoming SMS message to this number.
+
+   .. attribute:: sms_method
+
+      The HTTP method Twilio will use when making requests to the SmsUrl. Either GET or POST.
+
+   .. attribute:: sms_fallback_url
+
+      The URL that Twilio will request if an error occurs retrieving or executing the TwiML from SmsUrl.
+
+   .. attribute:: sms_fallback_method
+
+      The HTTP method Twilio will use when requesting the above URL. Either GET or POST.
+
+   .. attribute:: uri
+
+      The URI for this resource, relative to https://api.twilio.com.
+    """
+
 
     def load(self, entries):
         """ Set the proper Account owner of this phone number """
@@ -66,7 +185,11 @@ class PhoneNumber(InstanceResource):
             uri = re.sub(r'AC(.*)', entries["account_sid"],
                          self.parent.base_uri)
 
-            self.parent = PhoneNumbers(uri, self.parent.auth)
+            self.parent = PhoneNumbers(
+                uri,
+                self.parent.auth,
+                self.parent.timeout
+            )
             self.base_uri = self.parent.uri
 
         super(PhoneNumber, self).load(entries)
@@ -107,10 +230,10 @@ class PhoneNumbers(ListResource):
     key = "incoming_phone_numbers"
     instance = PhoneNumber
 
-    def __init__(self, base_uri, auth):
-        super(PhoneNumbers, self).__init__(base_uri, auth)
+    def __init__(self, base_uri, auth, timeout=UNSET_TIMEOUT):
+        super(PhoneNumbers, self).__init__(base_uri, auth, timeout)
         self.available_phone_numbers = \
-            AvailablePhoneNumbers(base_uri, auth, self)
+            AvailablePhoneNumbers(base_uri, auth, timeout, self)
 
     def delete(self, sid):
         """
@@ -139,6 +262,7 @@ class PhoneNumbers(ListResource):
 
         :returns: Returns a :class:`PhoneNumber` instance on success,
                   :data:`False` on failure
+        :raises: A :exc:`TypeError` if phone_number or area_code is not specified.
         """
         kwargs["StatusCallback"] = kwargs.get("status_callback",
                                               status_callback_url)
@@ -151,10 +275,10 @@ class PhoneNumbers(ListResource):
     def search(self, **kwargs):
         """
         :param type: The type of phone number to search for.
-        :param string country: Only show numbers for this country (iso2)
-        :param string region: When searching the US, show numbers in this state
-        :param string postal_code: Only show numbers in this area code
-        :param string rate_center: US only.
+        :param str country: Only show numbers for this country (iso2)
+        :param str region: When searching the US, show numbers in this state
+        :param str postal_code: Only show numbers in this area code
+        :param str rate_center: US only.
         :param tuple near_lat_long: Find close numbers within Distance miles.
         :param integer distance: Search radius for a Near- query in miles.
         """
