@@ -2,10 +2,35 @@ from twilio.rest.resources import InstanceResource, ListResource
 
 
 class Member(InstanceResource):
+    """ A Member of a queue
+
+   .. attribute:: call_sid
+
+      A 34 character string that uniquely identifies the call that is enqueued.
+
+   .. attribute:: date_enqueued
+
+      The date that the member was enqueued, given in RFC 2822 format.
+
+   .. attribute:: wait_time
+
+      The number of seconds the member has been in the queue.
+
+   .. attribute:: position
+
+      This member's current position in the queue.
+
+   .. attribute:: uri
+
+      The URI for this resource, relative to https://api.twilio.com.
+    """
+
+
     id_key = "call_sid"
 
 
 class Members(ListResource):
+    """ A list of :class:`Member` objects """
     name = "Members"
     instance = Member
     key = "queue_members"
@@ -14,7 +39,7 @@ class Members(ListResource):
         """
         Returns a list of :class:`Member` resources in the given queue
 
-        :param queue_sid: Queue this participant is part of
+        :param queue_sid: :class:`Queue` this participant is part of
         """
         return self.get_instances(kwargs)
 
@@ -32,6 +57,40 @@ class Members(ListResource):
 
 
 class Queue(InstanceResource):
+    """ An instance of a Queue
+
+   .. attribute:: sid
+
+      A 34 character string that uniquely identifies this queue.
+
+   .. attribute:: friendly_name
+
+      A user-provided string that identifies this queue.
+
+   .. attribute:: current_size
+
+      The count of calls currently in the queue.
+
+   .. attribute:: max_size
+
+      The upper limit of calls allowed to be in the queue.
+      `unlimited` is an option. The default is 100.
+
+   .. attribute:: average_wait_time
+
+      The average wait time of the members of this queue in seconds.
+      This is calculated at the time of the request.
+
+   .. attribute:: uri
+
+      The URI for this resource, relative to https://api.twilio.com.
+
+   .. attribute:: queue_members
+
+      A :class:`Members` object holding the :class:`Member` objects in this
+      queue.
+    """
+
 
     subresources = [
         Members
